babel: Internationalization utilities for Python
================================================

Description
-----------

A collection of tools for internationalizing Python applications.

Upstream Contact
----------------

http://babel.pocoo.org/en/latest/
